@@ -15,7 +15,8 @@ function(formula, data, subset, na.action, ...){
     m[[1]] <- as.name("model.frame")
     m$... <- NULL
     mf <- eval(m, parent.frame())
-    DNAME <- paste(names(mf), collapse = " by ")
+    DNAME <- paste(names(mf), collapse = " and ")
+    if (nchar(DNAME)>15) DNAME<-"x and y"
     groupname<-names(mf)[2]
 
     names(mf) <- NULL
@@ -24,11 +25,13 @@ function(formula, data, subset, na.action, ...){
     resp<-mf[[response]]
     out <- do.call("permTREND", c(list(x=resp,y=g), list(...)))
     out$data.name <- DNAME
+    names(out$estimate)<-names(out$null.value)<-paste("correlation of",DNAME)
+
     out
 }
 
 `permTREND.default` <-
-function(x, y, alternative = c("two.sided", "less", "greater","two.sidedAbs"), 
+function(x, y, alternative = c("two.sided", "less", "greater"), 
     exact = NULL, method=NULL, methodRule=methodRuleTREND1, 
     control=permControl(),...){
 
@@ -38,7 +41,8 @@ function(x, y, alternative = c("two.sided", "less", "greater","two.sidedAbs"),
     digits<-control$digits
     p.conf.level<-control$p.conf.level
     setSEED<-control$setSEED
-    
+    tsmethod<-control$tsmethod    
+
     if (!is.numeric(x) | !is.numeric(y) | !is.vector(x) | !is.vector(y) ) stop("x and y must be numeric vectors")
 
     if (length(x)!=length(y)) stop("x and y must be the same length")
@@ -47,24 +51,47 @@ function(x, y, alternative = c("two.sided", "less", "greater","two.sidedAbs"),
 
     method.OK<-(method=="pclt" | method=="exact.mc")
     if (!method.OK) stop("method not one of: 'pclt', 'exact.mc'")
+
+
+
+    ## program originally written so that tsmethod="abs" was 
+    ## alternative="two.sidedAbs", changed to avoid confusion with coin package
+    ## change it back internally
+    if (alternative[1]=="two.sidedAbs"){
+        warning("alternative='two.sidedAbs' may be deprecated in future versions,
+            use alternative='two.sided' and control=permControl(tsmethod='abs'))")
+        alternative<-"two.sided"
+        tsmethod<-"abs"
+    }
     alternative <- match.arg(alternative)
 
+    if (!(tsmethod=="central" | tsmethod=="abs") & alternative=="two.sided"){
+        stop("only tsmethod='central' and tsmethod='abs' allowed")
+    }
+    if (tsmethod=="abs" & alternative=="two.sided"){
+        alternative<-"two.sidedAbs"
+    } else if (tsmethod=="central" & alternative=="two.sided"){
+        alternative<-"two.sided"
+    }		
+
     mout<-switch(method,
         pclt=trend.pclt(x,y),
         exact.mc=trend.exact.mc(x,y,alternative,nmc,seed,digits,p.conf.level,setSEED))
     p.values<-mout$p.values
-
     PVAL <- switch(alternative,
         two.sided=p.values["p.twosided"],
         greater=p.values["p.gte"],
-        less=p.values["p.lte"]) 
+        less=p.values["p.lte"],two.sidedAbs=p.values["p.twosidedAbs"]) 
     if (method=="pclt") METHOD<-"Permutation Test using Asymptotic Approximation"
     else if (method=="exact.mc") METHOD<-"Exact Permutation Test Estimated by Monte Carlo"
-    xname<-deparse(substitute(x))
-    yname<-deparse(substitute(y))
-    if (length(xname)>1) xname<-c("x")
-    if (length(yname)>1) yname<-c("y")
-   
+    m<-match.call()
+    #xname<-deparse(substitute(x))
+    #yname<-deparse(substitute(y))
+    xname<-as.character(m$x)
+    yname<-as.character(m$y)
+
+    if (length(xname)>1 || nchar(xname)>10) xname<-c("RESPONSE")
+    if (length(yname)>1 || nchar(yname)>10) yname<-c("COVARIATE")
     DNAME <- paste(xname, "and", yname)
     Z<-mout$Z
     if (!is.null(Z)) names(Z)<-"Z"
